<TS version="2.1" language="br">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Kilikañ a-zehou evit cheñch an adres pe al label</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Krouiñ un adres nevez</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Nevez</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Eilañ</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Serriñ</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Dilemel an adres diuzet-mañ deus al listenn</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Lakaat adres pe label da glask</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Ezporzhiañ roadennoù an ivinell-mañ en ur rest</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Ezporzhiañ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Dilemel</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Choaz an adres ma 'vo kaset gwenneien dezhi</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Choaz an adres ma 'vo resevet gwenneien diganti</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">C&amp;hoaz</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Ho adresoù Bitcoin evit kas paeamantoù int. Gwirekaat ar sammad hag an adres a resev bewezh a-raok kas gwenneien.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Ho adresoù Bitcoin evit resev paeamantoù eo. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Eilañ Adres</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Eilañ &amp;Label</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">Ch&amp;eñch</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Ezporzhiañ Listenn an Adresoù</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Restr disrannet gant virgulennoù</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">Adresoù kas - %1</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">Adresoù resev - %1</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adres</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(label ebet)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Sifrañ an doug-moneiz</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Dibrennañ an doug-moneiz</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Cheñch frazenn-dremen</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Kadarnaat sifrañ an doug-moneiz</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Diwall: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Doug-moneiz sifret</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Doug-moneiz da sifrañ</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Sifret eo ho toug-moneiz bremañ. </translation>
    </message>
    </context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Fazi diabarzh</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Fazi : %1</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Sammad</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n second(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n day(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Sell hollek</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Treuzgreadoù</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">&amp;Kuitaat</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;A-zivout %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Diskouel titouroù a-zivout %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">A-zivout &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Diskouel titouroù a-zivout Qt</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Krouiñ un doug-moneiz nevez</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Bihanaat</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Doug-moneiz:</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Kas gwenneien d'un adres Bitcoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">Ka&amp;s</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Resev</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">Dibarzhi&amp;où…</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Sifrañ an doug-moneiz...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Serriñ an doug-moneiz...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Krouiñ un doug-moneiz...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Restr</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Arventennoù</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Sikour</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Fazi</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Diwall</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Titouroù</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Digeriñ un doug-moneiz</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Digeriñ un doug-moneiz</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Serriñ an doug-moneiz</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Anv doug-moneiz</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Prenestr</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">Zoum</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">Koac&amp;h</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">&amp;Diskouel</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Fazi : %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Diwall: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Deiziad: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Sammad: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Doug-moneiz: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Seurt: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Adres: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Eizhbit:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Sammad:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Fre:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Goude ar frejoù:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(di)diuzañ pep tra</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Mod gwezennad</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Mod listenn</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Sammad</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Deiziad</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Kadarnadurioù</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Kadarnaet</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Eilañ ar sammad</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Eilañ an adres</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Eilañ &amp;label</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Eilañ ar &amp;sammad</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Eilañ kementad</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Eilañ frejoù</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(label ebet)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Krouiñ un doug-moneiz</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Digeriñ un doug-moneiz</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Serriñ an doug-moneiz</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Krouiñ un doug-moneiz</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Anv doug-moneiz</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Doug-moneiz</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Krouiñ</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Adres</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation type="unfinished">anv</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">versioñ</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">A-zivout %1</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Donemat</translation>
    </message>
    <message>
        <source> GB</source>
        <translation type="unfinished"> Ge</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Fazi</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Furmskrid</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="unfinished">Achp</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Dibarzhioù</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished">Ge</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation type="unfinished">Mie</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">&amp;Doug-moneiz</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation type="unfinished">&amp;IP ar proksi:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Prenestr</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished">&amp;Skrammañ</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation type="unfinished">&amp;Yezh an etrefas:</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation type="unfinished">Yezh an etrefas a c'hall bezañ cheñchet amañ. Efecktivel vo an arventenn-mañ vo goude adloc'hañ %1.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Nullañ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Nullañ</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Fazi</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Furmskrid</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Serriñ</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">pe</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Peer</source>
        <extracomment>Title of Peers Table column which contains a unique number used to identify a connection.</extracomment>
        <translation type="unfinished">Par</translation>
    </message>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">Oad</translation>
    </message>
    <message>
        <source>Sent</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have sent to the peer.</extracomment>
        <translation type="unfinished">Kaset</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Adres</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Seurt</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Rouedad</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Network</source>
        <translation type="unfinished">Rouedad</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Anv</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Doug-moneiz: </translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished">Kaset</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">&amp;Eilañ an adres</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Ya</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">Ket</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Da</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Deus</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">S&amp;ammad:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Eilañ an adres</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Eilañ &amp;label</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Eilañ ar &amp;sammad</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Sammad:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Doug-moneiz:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Deiziad</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(label ebet)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Eizhbit:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Sammad:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Fre:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Goude ar frejoù:</translation>
    </message>
    <message>
        <source>Choose…</source>
        <translation type="unfinished">Choaz…</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Eilañ kementad</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Eilañ ar sammad</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Eilañ frejoù</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">pe</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(label ebet)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">Sa&amp;mmad:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signature</source>
        <translation type="unfinished">Sinadur</translation>
    </message>
    <message>
        <source>No error</source>
        <translation type="unfinished">Fazi ebet</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Deiziad</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Deus</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Da</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation type="unfinished">Treuzgread</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Sammad</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Deiziad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Seurt</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Minet</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(label ebet)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation type="unfinished">Hirie</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Minet</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Traoù all</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Eilañ an adres</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Eilañ &amp;label</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Eilañ ar &amp;sammad</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Restr disrannet gant virgulennoù</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Kadarnaet</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Deiziad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Seurt</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adres</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished">da</translation>
    </message>
</context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Krouiñ un doug-moneiz nevez</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Fazi</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Ezporzhiañ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Ezporzhiañ roadennoù an ivinell-mañ en ur rest</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Nullañ</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error: Address book data in wallet cannot be identified to belong to migrated wallets</source>
        <translation type="unfinished">Fazi: Address book data in wallet cannot be identified to belong to migrated wallets</translation>
    </message>
    <message>
        <source>Error: Duplicate descriptors created during migration. Your wallet may be corrupted.</source>
        <translation type="unfinished">Fazi: Duplicate descriptors created during migration. Your wallet may be corrupted.</translation>
    </message>
    <message>
        <source>Error: Transaction %s in wallet cannot be identified to belong to migrated wallets</source>
        <translation type="unfinished">Fazi: Transaction %s in wallet cannot be identified to belong to migrated wallets</translation>
    </message>
    <message>
        <source>Error creating %s</source>
        <translation type="unfinished">Fazi en ur grouiñ %s</translation>
    </message>
    <message>
        <source>Error: Cannot extract destination from the generated scriptpubkey</source>
        <translation type="unfinished">Fazi: Cannot extract destination from the generated scriptpubkey</translation>
    </message>
    <message>
        <source>Error: Couldn't create cursor into database</source>
        <translation type="unfinished">Fazi: Couldn't create cursor into database</translation>
    </message>
    <message>
        <source>Error: Disk space is low for %s</source>
        <translation type="unfinished">Fazi: Disk space is low for %s</translation>
    </message>
    <message>
        <source>Error: Dumpfile checksum does not match. Computed %s, expected %s</source>
        <translation type="unfinished">Fazi: Dumpfile checksum does not match. Computed %s, expected %s</translation>
    </message>
    <message>
        <source>Error: Failed to create new watchonly wallet</source>
        <translation type="unfinished">Fazi: Failed to create new watchonly wallet</translation>
    </message>
    <message>
        <source>Error: Missing checksum</source>
        <translation type="unfinished">Fazi: Sammad-gwiriañ o vankout</translation>
    </message>
    <message>
        <source>Error: No %s addresses available.</source>
        <translation type="unfinished">Fazi: Adres %s hegerz ebet.</translation>
    </message>
    <message>
        <source>Error: This wallet already uses SQLite</source>
        <translation type="unfinished">Fazi: Implijet eo dija SQLite gant an doug-moneiz-mañ</translation>
    </message>
    <message>
        <source>Error: Unable to remove watchonly address book data</source>
        <translation type="unfinished">Fazi: Unable to remove watchonly address book data</translation>
    </message>
    <message>
        <source>Error: Could not add watchonly tx %s to watchonly wallet</source>
        <translation type="unfinished">Fazi: Could not add watchonly tx %s to watchonly wallet</translation>
    </message>
    </context>
</TS>